@@ -28,8 +28,13 @@ from .resource_collections import Variant
 
 def recursive_update(dest, source):
     """Like dict.update, but recursive"""
+    try:
+        from collections.abc import Mapping
+    except ImportError:
+        from collections import Mapping
+
     for key, val in six.iteritems(source):
-        if isinstance(val, collections.Mapping):
+        if isinstance(val, Mapping):
             recurse = recursive_update(dest.get(key, {}), val)
             dest[key] = recurse
         else:
